# generated by datamodel-codegen:
#   filename:  enums/standard_format_ids.json
#   timestamp: 2025-11-29T12:00:45+00:00

from __future__ import annotations

from enum import Enum


class StandardFormatIds(Enum):
    display_300x250 = 'display_300x250'
    display_728x90 = 'display_728x90'
    display_320x50 = 'display_320x50'
    display_160x600 = 'display_160x600'
    display_970x250 = 'display_970x250'
    display_336x280 = 'display_336x280'
    display_expandable_300x250 = 'display_expandable_300x250'
    display_expandable_728x90 = 'display_expandable_728x90'
    display_interstitial_320x480 = 'display_interstitial_320x480'
    display_interstitial_desktop = 'display_interstitial_desktop'
    display_dynamic_300x250 = 'display_dynamic_300x250'
    display_responsive = 'display_responsive'
    native_in_feed = 'native_in_feed'
    native_content_recommendation = 'native_content_recommendation'
    native_product = 'native_product'
    video_skippable_15s = 'video_skippable_15s'
    video_skippable_30s = 'video_skippable_30s'
    video_non_skippable_15s = 'video_non_skippable_15s'
    video_non_skippable_30s = 'video_non_skippable_30s'
    video_outstream_autoplay = 'video_outstream_autoplay'
    video_vertical_story = 'video_vertical_story'
    video_rewarded_30s = 'video_rewarded_30s'
    video_pause_ad = 'video_pause_ad'
    video_ctv_non_skippable_30s = 'video_ctv_non_skippable_30s'
    audio_standard_15s = 'audio_standard_15s'
    audio_standard_30s = 'audio_standard_30s'
    audio_podcast_host_read = 'audio_podcast_host_read'
    audio_programmatic = 'audio_programmatic'
    universal_carousel = 'universal_carousel'
    universal_canvas = 'universal_canvas'
    universal_takeover = 'universal_takeover'
    universal_gallery = 'universal_gallery'
    universal_reveal = 'universal_reveal'
    dooh_landscape_static = 'dooh_landscape_static'
    dooh_portrait_video = 'dooh_portrait_video'
