# generated by datamodel-codegen:
#   filename:  core/promoted_products.json
#   timestamp: 2025-11-29T12:00:45+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class PromotedProducts(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    manifest_category: Annotated[
        str | None,
        Field(
            description="Select products from a specific category in the brand manifest product catalog (e.g., 'beverages/soft-drinks', 'food/sauces')"
        ),
    ] = None
    manifest_query: Annotated[
        str | None,
        Field(
            description="Natural language query to select products from the brand manifest (e.g., 'all Kraft Heinz pasta sauces', 'organic products under $20')"
        ),
    ] = None
    manifest_skus: Annotated[
        list[str] | None,
        Field(description='Direct product SKU references from the brand manifest product catalog'),
    ] = None
    manifest_tags: Annotated[
        list[str] | None,
        Field(
            description="Select products by tags from the brand manifest product catalog (e.g., 'organic', 'sauces', 'holiday')"
        ),
    ] = None
