# generated by datamodel-codegen:
#   filename:  core/frequency_cap.json
#   timestamp: 2025-11-29T12:00:45+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class FrequencyCap(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    suppress_minutes: Annotated[
        float, Field(description='Minutes to suppress after impression', ge=0.0)
    ]
