# generated by datamodel-codegen:
#   filename:  core/assets/video_asset.json
#   timestamp: 2025-12-18T20:00:24+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, ConfigDict, Field


class VideoAsset(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    bitrate_kbps: Annotated[
        int | None, Field(description='Video bitrate in kilobits per second', ge=1)
    ] = None
    duration_ms: Annotated[
        int | None, Field(description='Video duration in milliseconds', ge=1)
    ] = None
    format: Annotated[str | None, Field(description='Video file format (mp4, webm, mov, etc.)')] = (
        None
    )
    height: Annotated[int, Field(description='Height in pixels', ge=1)]
    url: Annotated[AnyUrl, Field(description='URL to the video asset')]
    width: Annotated[int, Field(description='Width in pixels', ge=1)]
