# generated by datamodel-codegen:
#   filename:  core/assets/audio_asset.json
#   timestamp: 2025-11-29T12:00:45+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, ConfigDict, Field


class AudioAsset(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    bitrate_kbps: Annotated[
        int | None, Field(description='Audio bitrate in kilobits per second', ge=1)
    ] = None
    duration_ms: Annotated[
        int | None, Field(description='Audio duration in milliseconds', ge=0)
    ] = None
    format: Annotated[str | None, Field(description='Audio file format (mp3, wav, aac, etc.)')] = (
        None
    )
    url: Annotated[AnyUrl, Field(description='URL to the audio asset')]
